Method: Slideshow::Gen#guard_text

Defined in:
lib/slideshow/commands/gen.rb

#guard_text(text) ⇒ Object

some markdown guard helpers

(e.g. guard text/mark text for do NOT convert)


63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/slideshow/commands/gen.rb', line 63

def guard_text( text )
  # todo/fix 2: note we need to differentiate between blocks and inline
  #   thus, to avoid runs - use guard_block (add a leading newline to avoid getting include in block that goes before)
  
  # todo/fix: remove wrap_markup; replace w/ guard_text
  #   why: text might be css, js, not just html
  
  ###  !!!!!!!!!!!!
  ## todo: add print depreciation warning
  
  wrap_markup( text )
end